% This m-file if part of an m-script collection with the aim
% to prove or disprove the claims of Dr. Randell Mills in his grand unified theory
% of classical physics (GUTCP)
% http://brilliantlightpower.com/book-download-and-streaming/

clear % delete all variables from the workspace
close all % closes all open figures (plot windows)

% ######### control the script behavior ##############
format long;
visual_inspection = false;

% ######### physical constants #######################

mu_0 = 4*pi*10^-7;         % Vacuum permeability in [N/A^2]
c_0 = 299792458;           % speed of light in vacuum  [m/s]
ec = 1.6021766208*10^-19;  % elementary charge [C]
h = 6.626070040*10^-34;    % plank constant [J*s]
h_bar = 1.0545718 *10^-34; % reduced plank constant [J*s]
eps_0 = 1/(mu_0*c_0^2);    % Vacuum permittivity in [F/m]
m_e = 9.10938356*10^-31;   % mass of the electron [kg]
m_p = 1.672621898*10^-27;  % mass of the proton [kg]
alpha = (mu_0*ec^2*c_0)/(2*h); % fine structure constant []
a_0 = 5.2917721067*10^-11;    % Bohr radius [m]
mu_b = 9.274009994*10^-24;    % Bohr magneton [J/T]
angstrom = 10^-10;         % one angstrom [m]

% ######## solving for geometric parameter a ##########
% Ionization energy of oxigen from literature (https://dept.astro.lsa.umich.edu/~cowley/ionen.htm):
e_ox_ion_lit_eV = 13.6181; %in eV
% Needed parameters:
% GUTCP claims, that it can calculate the ionization energies. This looks rather
% lengthy but I hope it´s worth the trouble - let´s go!
% GUTCP p.315 (10.51)
Z = 8; % number of protons in oxigen
r1= a_0*(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
% r1 in units of a_0 (as is used in GUTCP formulars)
r1_a_0=(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
r2=r1;
% GUTCP p.316 (10.62)
% long term split in 3 parts
r4_p1=(a_0*(1-(sqrt(3/4))/(Z)))/((Z-3)-(1/4-1/Z)*(sqrt(3/4))/(r1_a_0));
r4_p2=(1-(sqrt(3/4))/Z)^2/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0)^2;
r4_p3=4*(((Z-3)/(Z-2))*r1_a_0*10*sqrt(3/4))/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0);
r4=(r4_p1+a_0*sqrt(r4_p2+r4_p3))/2; % (+) chosen to get a positiv distance
r4_a_0=r4/a_0;
r3=r4;
r3_a_0=r4_a_0;
% GUTCP p.334 (10.161)
r8=a_0/((Z-7)-(1/4-2/Z)*sqrt(3/4)/r3_a_0);
% GUTCP p.334 (10.163)
e_ox_ion_gutcp = (Z-7)*ec^2/(8*pi*eps_0*r8);
% from Joule to eV
e_ox_ion_gutcp_eV = e_ox_ion_gutcp/ec;
disp(['']);
disp(['']);
disp('############ Results for hydroxyl radical - OH ##################')
disp(['Calculated value for ionization energy of oxigen is ',num2str(e_ox_ion_gutcp_eV),'eV.'])
disp(['Mills value is                                      13.60580eV.'])
disp(['This gives an relative error of ',num2str(abs(100*(e_ox_ion_gutcp_eV-13.6058)/e_ox_ion_gutcp_eV)),'% between my result and the value Mills gives in is GUTCP.'])
disp(['This gives an relative error of ',num2str(abs(100*(e_ox_ion_lit_eV-e_ox_ion_gutcp_eV)/e_ox_ion_lit_eV)),'% between my result and the experimental value from NIST.'])

% p.468 (11.212)
e_h2_ion = -ec^2/(8*pi*eps_0*a_0)*((2*sqrt(2)-sqrt(2)+sqrt(2)/2)*log((sqrt(2)+1)/(sqrt(2)-1))-sqrt(2));
e_h2_ion_eV = e_h2_ion/ec;

% GUT equation 13.77 in the form f(a)=0
eq_13_77 =@(a) (ec^2/(8*pi*eps_0*sqrt((2*a*a_0)/3))*(((3/2)-(3/8)*a_0/a)*log((a+sqrt(2*a*a_0/3))/(a-sqrt(2*a*a_0/3)))-1)-ec*(-e_h2_ion_eV-e_ox_ion_gutcp_eV));

% Visual inspection is important, because many solvers for f(a)=0 fail when f() 
% is a nonlinear function. To see if the result is valid and most important, if
% there are other real solutions than the one found by the algorithm these solutions also
% have to be considered. In this case there is just one real solution in a 
% physical meaningful range (I did not extend the function evalution to several
% meters).
if(visual_inspection == true)
  % range of values for "a" that shall be inspected
  range = (10^-13:10^-13:10^-8)';
  % preallocating space for the function values
  f_values = zeros(numel(range),1);
  % eveluate equation 13.77 for every point of vector "range"
  for i=1:numel(range)
      % This function eq_13_77_complex_to_nan() is used, to set every complex value to NaN (not a number) because
      % the plot function does not like complex numbers.
      f_values(i) = eq_13_77_complex_to_nan(range(i));
  end
  %Plot the results
  plot(range,f_values)
  xlabel('Range of possible values for "a"')
  ylabel('Output of equation 13.77')
  title(' Physical realistic range of values for "a" - Just one real solution for f(a)=0')
end


% Parameters for optimization algorithm
% Visual Inspection gave a good starting point for the search of the solution to f(a)=0.
% The "search range" was set to this small range, because in this range there are no
% complex values for f(a). The function fzero() gives errors while encountering complex values.
start_val = [5*10^-11,8*10^-11];
MAXITER = 100; % Maximum number of iterations for the solving algorithm
TOL = 10^-200; 
MAXEVALS = 100;

% type "help optimset" to the octave command window to see all possible options
options = optimset('Display','iter','TolX',TOL,'MaxFunEvals',MAXEVALS,'MaxIter',MAXITER);
% Get the solution ("a" in Mills formulars is a_ here in the script)!
[a_,fval,exitflag,output] = fzero(eq_13_77,start_val,options);
% Print result to octave command window
disp(['']);
disp(['Calculated value for "a" is ',num2str(a_),'.'])
disp(['Mills value for "a" is      6.69039e-11.'])
disp(['This gives an relative error of ',num2str(abs(100*(a_-6.69039*10^-11)/a_)),'% between my result and the value Mills gives in his GUTCP.'])

% ######## Calculating different energy contributions ##########
% (1)##### Molecular orbital (MO) energy #######################
% calculating missing values with the knowledge of value for "a"
% geometric meaning of these values best seen in graphic on p.469 of GUTCP
c_=sqrt((2*a_*a_0)/3);
b_=sqrt(a_^2-c_^2);
eccentricity = c_/a_;
% Print result to octave command window
disp(['']);
disp(['Calculated value for the internuclear distance is   ',num2str(2*c_),'m.'])
disp(['Mills literature value for internuclear distance is 9.71e-11 m.'])
disp(['The literature value I found is                     9.6966e-11 m. (http://webbook.nist.gov/cgi/inchi?ID=C3352576&Mask=1000)'])
disp(['This gives an relative error of ',num2str(abs(100*((2*c_)-9.6966*10^-11)/(2*c_))),'% between my result and the value from NIST.'])
% GUTCP p.468 (13.73) - Total energy of MO (electrons)
E_T=-ec^2/(8*pi*eps_0*c_)*((3/2-(3/8)*(a_0/a_))*log((a_+c_)/(a_-c_))-1);
% GUTCP p.468 (13.74) - Linearcombination
E_T_OH = E_T - e_ox_ion_gutcp;
% Joule to eV
E_T_OH_eV = E_T_OH/ec;
% (2)##### Magnetic coupling energy #######################
% GUTCP p.474 (13.152) in eV
E_mag_eV = (8*pi*mu_0*mu_b^2/a_0^3)/ec;
% (3)##### Kinetic energy #######################
% GUTCP p.475 (13.143) in eV
E_kin_eV = (h_bar*sqrt(((0.75*ec^2)/(4*pi*eps_0*b_^3))/m_e))/ec;
% (4)##### Doppler energy #######################
% GUTCP p.474 (13.144) in eV
E_dop_eV = E_T_OH_eV*sqrt(2*ec*E_kin_eV/(m_e*c_0^2));
% (5)##### Vibrational energy #######################
% p.472 (13.107) - reduced nuclear mass 
m_reduced = (1*16)/(1+16)*m_p;
% p.472 (13.106) - spring constant (see (11.136))
k_spring = ((0.75*ec^2)/(8*pi*eps_0*b_^3)-(ec^2)/(8*pi*eps_0*(2*c_)^3));
w_ang_freq_osc = sqrt(k_spring/m_reduced);
% (13.110)
E_vib = h_bar*w_ang_freq_osc;
E_vib_eV = E_vib/ec;
% Conversion factor from eV to cm^-1
eV_to_cm1 = 8065.5; % http://www.pci.tu-bs.de/aggericke/Konstanten.html
E_vib_cm1 = E_vib_eV*eV_to_cm1;
disp(['']);
disp(['Calculated value for vibrational energy of hydroxyl is ',num2str(E_vib_cm1),'cm^-1.'])
disp(['Value from Literatur                                   3737.76cm^-1. (http://webbook.nist.gov/cgi/inchi?ID=C3352576&Mask=1000)'])
disp(['This gives an relative error of ',num2str(abs(100*(E_vib_cm1-3737.76)/E_vib_cm1)),'% between my result and NIST value.'])
% (6)##### Total bond energy #######################
% p.475 (13.145)
E_osc_eV = E_dop_eV+1/2*E_vib_eV;
% To rule out the last (magical) number the ionization energy of H has to be calculated
% p.120 (1.293)
A=1; % mass number of H - 1 proton no neutron
Z=1; % number of protons of h
term1=((alpha*Z)^2*m_e*c_0^2)/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2)+m_e/(m_p*A));
term2=m_e*c_0^2*(1/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2))-1);
e_h_ion=term1-term2;
e_h_ion_eV = e_h_ion/ec;
% p.475 (13.148)
E_T_OSC_eV = E_T_OH_eV + E_osc_eV;
E_D = -(e_ox_ion_gutcp_eV+e_h_ion_eV)-(E_T_OSC_eV+E_mag_eV);
E_D_literature = 423.8/96.485; % kJ/mol to eV(https://books.google.de/books?id=LaS-BwAAQBAJ&pg=PA130&lpg=PA130&dq=dissociation+energy+hydroxyl+without+temperature&source=bl&ots=zDe9RCxrDB&sig=mljwDGzbxibghUBHDtZnWQuorJw&hl=de&sa=X&ved=0ahUKEwiR7Y_rnLXPAhXGIsAKHcL5BnYQ6AEIQzAF#v=onepage&q=dissociation%20energy%20hydroxyl%20without%20temperature&f=false)
disp(['']);
disp(['Calculated value for bond dissociation energy of hydroxyl is ',num2str(E_D),'eV.'])
disp(['Value from Literatur according to Mills                      4.4104 eV. (no online source found - ToDo: Search independant value)'])
disp(['Value from Literatur I found (+-2.1eV standard deviation)    ',num2str(E_D_literature),'eV. (onlinesource as comment in the calculation skript)'])
disp(['This gives an relative error of ',num2str(abs(100*(E_D-4.4104)/E_D)),'% between my result and the literature value of Mills.'])
disp(['']);
disp(['']);
