% This m-file if part of an m-script collection with the aim
% to prove or disprove the claims of Dr. Randell Mills in his grand unified theory
% of classical physics (GUTCP)
% http://brilliantlightpower.com/book-download-and-streaming/

clear % delete all variables from the workspace
close all % closes all open figures (plot windows)

% ######### control the script behavior ##############
format long;
visual_inspection = false; % it takes some time to calculate the plots => default off

% ######### physical constants #######################

mu_0 = 4*pi*10^-7;         % Vacuum permeability in [N/A^2]
c_0 = 299792458;           % speed of light in vacuum  [m/s]
ec = 1.6021766208*10^-19;  % elementary charge [C]
h = 6.626070040*10^-34;    % plank constant [J*s]
h_bar = 1.0545718 *10^-34; % reduced plank constant [J*s]
eps_0 = 1/(mu_0*c_0^2);    % Vacuum permittivity in [F/m]
m_e = 9.10938356*10^-31;   % mass of the electron [kg]
m_p = 1.672621898*10^-27;  % mass of the proton [kg]
alpha = (mu_0*ec^2*c_0)/(2*h); % fine structure constant []
a_0 = 5.2917721067*10^-11;    % Bohr radius [m]
mu_b = 9.274009994*10^-24;    % Bohr magneton [J/T]

% ######## solving for geometric parameter a ##########

% Needed parameters:
% GUTCP claims, that it can calculate the ionization energies. This looks rather
% lengthy but I hope it´s worth the trouble - let´s go!
% GUTCP p.315 (10.51)
Z = 8; % number of protons in oxigen
r1= a_0*(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
% r1 in units of a_0 (as is used in GUTCP formulars)
r1_a_0=(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
r2=r1;
% GUTCP p.316 (10.62)
% long term split in 3 parts
r4_p1=(a_0*(1-(sqrt(3/4))/(Z)))/((Z-3)-(1/4-1/Z)*(sqrt(3/4))/(r1_a_0));
r4_p2=(1-(sqrt(3/4))/Z)^2/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0)^2;
r4_p3=4*(((Z-3)/(Z-2))*r1_a_0*10*sqrt(3/4))/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0);
r4=(r4_p1+a_0*sqrt(r4_p2+r4_p3))/2; % (+) chosen to get a positiv distance
r4_a_0=r4/a_0;
r3=r4;
r3_a_0=r4_a_0;
% GUTCP p.334 (10.161)
r8=a_0/((Z-7)-(1/4-2/Z)*sqrt(3/4)/r3_a_0);
% GUTCP p.334 (10.163)
e_ox_ion_gutcp = (Z-7)*ec^2/(8*pi*eps_0*r8);
% from Joule to eV
e_ox_ion_gutcp_eV = e_ox_ion_gutcp/ec;

% p.468 (11.212)
e_h2_ion = -ec^2/(8*pi*eps_0*a_0)*((2*sqrt(2)-sqrt(2)+sqrt(2)/2)*log((sqrt(2)+1)/(sqrt(2)-1))-sqrt(2));
e_h2_ion_eV = e_h2_ion/ec;
% p.479 (13.180)
e_2h2_O_ion_eV = 2*e_h2_ion_eV+e_ox_ion_gutcp_eV;

% The needed parameter is calculated - proceed with the water equations:

% GUT equation 13.182 in the form f(a)=0
eq_13_182 =@(a) (ec^2/(4*pi*eps_0*sqrt((2*a*a_0)/3))*(((3/2)-(3/8)*a_0/a)*log((a+sqrt(2*a*a_0/3))/(a-sqrt(2*a*a_0/3)))-1)-ec*(-e_2h2_O_ion_eV-e_ox_ion_gutcp_eV));

% Visual inspection is important, because many solvers for f(a)=0 fail when f() 
% is a nonlinear function. To see if the result is valid and most important, if
% there are other real solutions than the one found by the algorithm these solutions also
% have to be considered. In this case there is just one real solution in a 
% physical meaningful range (I did not extend the function evalution to several
% meters).
if(visual_inspection == true)
  % range of values for "a" that shall be inspected
  range = (10^-13:10^-13:10^-8)';
  % preallocating space for the function values
  f_values = zeros(numel(range),1);
  % eveluate equation 13.182 for every point of vector "range"
  for i=1:numel(range)
      % This function eq_13_182_complex_to_nan() is used, to set every complex value to NaN (not a number) because
      % the plot function does not like complex numbers.
      f_values(i) = eq_13_182_complex_to_nan(range(i));
  end
  %Plot the results
  figure(1)
  plot(range,f_values)
  xlabel('Range of possible values for "a"')
  ylabel('Output of equation 13.182')
  title(' Physical realistic range of values for "a" - Just one real solution for f(a)=0')
end


% Parameters for optimization algorithm
% Visual Inspection gave a good starting point for the search of the solution to f(a)=0.
% The "search range" was set to this small range, because in this range there are no
% complex values for f(a). The function fzero() gives errors while encountering complex values.
start_val = [5*10^-11,8*10^-11];
MAXITER = 100; % Maximum number of iterations for the solving algorithm
TOL = 10^-200; 
MAXEVALS = 100;

% type "help optimset" to the octave command window to see all possible options
options = optimset('Display','iter','TolX',TOL,'MaxFunEvals',MAXEVALS,'MaxIter',MAXITER);
% Get the solution ("a" in Mills formulars is a_ here in the script)!
[a_,fval,exitflag,output] = fzero(eq_13_182,start_val,options);
disp('############ Results for water molecule - H2O ##################')
% Print result to octave command window
disp(['Calculated value for "a" is ',num2str(a_),'.'])
disp(['Mills value for "a" is      6.68933e-11.'])
disp(['This gives an relative error of ',num2str(abs(100*(a_-6.68933*10^-11)/a_)),'% between my result and the value Mills gives in is GUTCP.'])

% ######## Calculating different energy contributions ##########
% (1)##### Molecular orbital (MO) energy #######################
% calculating missing values with the knowledge of value for "a"
% geometric meaning of these values best seen in graphic on p.469 of GUTCP
c_=sqrt((2*a_*a_0)/3);
b_=sqrt(a_^2-c_^2);
eccentricity = c_/a_; %
disp([''])
disp(['Calculated value for internuclear distance is ',num2str(2*c_),'m.'])
disp(['Experimental value is according to Mills      9.7e-11m. No online source found but I did not try hard :-)'])

% GUTCP p.479 (13.180) - Calculated above
E_T_H20_eV = e_2h2_O_ion_eV;

%% ##### Doppler energy #######################
% p.482 (13.209) 
w_ang_freq_osc = sqrt(((3/2)*(ec^2)/(4*pi*eps_0*b_^3))/(m_e));
% p.482 (13.210)
E_kin_eV = h_bar*w_ang_freq_osc/ec;
% (13.211)
E_dop_eV = E_T_H20_eV*sqrt((2*ec*E_kin_eV)/(m_e*c_0^2));
% ##### Total bond energy #######################
% p.483 (13.218)
E_osc_eV = 2*(E_dop_eV+(1/2)*(3756/8065.5)); % EXPERIMENTAL VALUE - TO CALCULATE USE(eq. 15.98)!!!
disp([''])
disp(['For the vibrational energy the equation was not given and I was too stupid to derive it.'])
disp(['Instead I took the value from http://webbook.nist.gov/cgi/cbook.cgi?ID=C7732185&Mask=800'])
disp(['and converted it to eV. The generic equation for this value is (more or less) 15.98'])
disp(['but to use it I have to study the "generic chapter" more deeply.'])
disp([''])
% p.483 (13.216)
E_T_OSC_eV = E_T_H20_eV + E_osc_eV;
%   ##### Copied lines from other scripts to get rid of magical numbers #######################
    % To rule out a magical number the ionization energy of H has to be calculated
    % p.120 (1.293)
    A=1; % mass number of H - 1 proton no neutron
    Z=1; % number of protons of h
    term1=((alpha*Z)^2*m_e*c_0^2)/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2)+m_e/(m_p*A));
    term2=m_e*c_0^2*(1/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2))-1);
    e_h_ion=term1-term2;
    e_h_ion_eV = e_h_ion/ec;
    % Energy of hydroxyl has to be calculated (copied from hydroxyl_radical.m)#
    % Comments deleted to decrease number of lines
    % p.468 (11.212)
    e_h2_ion = -ec^2/(8*pi*eps_0*a_0)*((2*sqrt(2)-sqrt(2)+sqrt(2)/2)*log((sqrt(2)+1)/(sqrt(2)-1))-sqrt(2));
    e_h2_ion_eV = e_h2_ion/ec;
    eq_13_77 =@(a) (ec^2/(8*pi*eps_0*sqrt((2*a*a_0)/3))*(((3/2)-(3/8)*a_0/a)*log((a+sqrt(2*a*a_0/3))/(a-sqrt(2*a*a_0/3)))-1)-ec*(-e_h2_ion_eV-e_ox_ion_gutcp_eV));
    start_val = [5*10^-11,8*10^-11];
    MAXITER = 100; % Maximum number of iterations for the solving algorithm
    TOL = 10^-200; 
    MAXEVALS = 100;
    options = optimset('Display','iter','TolX',TOL,'MaxFunEvals',MAXEVALS,'MaxIter',MAXITER);
    [a_O_H,fval,exitflag,output] = fzero(eq_13_77,start_val,options);
    c_O_H=sqrt((2*a_O_H*a_0)/3);
    b_O_H=sqrt(a_O_H^2-c_O_H^2);
    eccentricity = c_O_H/a_O_H; %
    E_T=-ec^2/(8*pi*eps_0*c_)*((3/2-(3/8)*(a_0/a_O_H))*log((a_O_H+c_O_H)/(a_O_H-c_O_H))-1);
    E_T_OH = E_T - e_ox_ion_gutcp;
    E_T_OH_eV = E_T_OH/ec;
    E_mag_eV = (8*pi*mu_0*mu_b^2/a_0^3)/ec;
% p.483 (13.222)
E_bond_diss_eV = -e_h_ion_eV+E_T_OH_eV-E_mag_eV-E_T_OSC_eV;
disp([''])
disp(['Calculated bond dissociation energy of water is ',num2str(E_bond_diss_eV),'eV.'])
disp(['Experimental value is                           ',num2str(493.4*0.01036),'eV.'])
disp(['(https://en.wikipedia.org/wiki/Bond-dissociation_energy)'])
disp(['This gives an relative error of ',num2str(abs(100*(E_bond_diss_eV-(493.4*0.01036))/E_bond_diss_eV)),'%'])
disp(['between my result and the experimental value.'])

% ##### Bond Angles #######################
% (13.233) It is possible that I made a small error in the next line, because the 
% overall result is not as good as I am used to :-) 
eq_13_233 =@(a) (-ec^2/(8*pi*eps_0*sqrt((a*a_0)/(2))))*((3/2-(3*a_0)/(8*a))*log((a+sqrt((a*a_0)/(2)))/(a-sqrt((a*a_0)/(2))))-1)*(1+sqrt((2*h_bar*sqrt((0.75*ec^2)/(4*pi*eps_0*a^3)/m_e))/(m_e*c_0^2)))+(1/2*h_bar*sqrt(((0.75*ec^2)/(8*pi*eps_0*a^3)-ec^2/(8*pi*eps_0*(a+sqrt((2*a*a_0)/(3)))^3))/(0.5*m_p)));

if(visual_inspection == true)
  % range of values for "a" that shall be inspected
  range = (10^-13:10^-13:10^-8)';
  % preallocating space for the function values
  f_values = zeros(numel(range),1);
  % eveluate equation 13.233 for every point of vector "range"
  for i=1:numel(range)
      % This function eq_13_233_complex_to_nan() is used, to set every complex value to NaN (not a number) because
      % the plot function does not like complex numbers.
      f_values(i) = eq_13_233_complex_to_nan(range(i));
  end
  %Plot the results
  figure(2)
  plot(range,f_values)
  xlabel('Range of possible values for "a"')
  ylabel('Output of equation 13.233')
  title(' Physical realistic range of values for "a" - Just one real solution for f(a)=0')
end

% Parameters for optimization algorithm
% Visual Inspection gave a good starting point for the search of the solution to f(a)=0.
% The "search range" was set to this small range, because in this range there are no
% complex values for f(a). The function fzero() gives errors while encountering complex values.
start_val = [1*10^-10,4*10^-10];
MAXITER = 100; % Maximum number of iterations for the solving algorithm
TOL = 10^-200; 
MAXEVALS = 100;

% type "help optimset" to the octave command window to see all possible options
options = optimset('Display','iter','TolX',TOL,'MaxFunEvals',MAXEVALS,'MaxIter',MAXITER);
[a_h_h,fval,exitflag,output] = fzero(eq_13_233,start_val,options);
% p.484 (13.228)
c_h_h = sqrt((a_h_h*a_0)/2);
% p. 477 (13.167)
bh_h = sqrt(a_h_h^2-c_h_h^2);
ch_h = bh_h;
% (13.168)
eh_h = c_h_h/a_h_h;
% p.485 (13.242)
H2O_bond_angle_deg = acos((2*(2*c_O_H)^2-(2*c_h_h)^2)/(2*(2*c_O_H)^2))*180/pi;
disp([''])
disp(['Calculated bond angle of water is ',num2str(H2O_bond_angle_deg),' degree.'])
disp(['Mills value is                    105.998 degree.'])
disp(['This gives an relative error of ',num2str(abs(100*(H2O_bond_angle_deg-105.998)/H2O_bond_angle_deg)),'% between my result and the value Mills gives in is GUTCP.'])
disp(['This error is pretty high compared to the other deviations of Mills value and mine.'])
disp(['It is possible that I made a small error in eq. 13.223. This thing is quite large :-)'])
disp(['The absolute error is in my eyes too small to spend much time in error searching. So I leave it to this value for now.'])
disp(['']);
disp(['']);